# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-06-11 12:02
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('reversion', '0003_auto_20160601_1600'),
    ]

    operations = [
        migrations.AlterField(
            model_name='version',
            name='db',
            field=models.CharField(help_text='The database the model under version control is stored in.', max_length=191),
        ),
        migrations.AlterUniqueTogether(
            name='version',
            unique_together=set([('db', 'content_type', 'object_id', 'revision')]),
        ),
    ]
